
# Version 1.1.0

+ Update required version of PERMETRICS to 1.5.0
+ **Speed up 10x-100x** for the computation time of objective functions.
+ Update all cluster_finder methods.
+ Add customization functions to save figures. 
+ Update documents, examples, ChangeLog.md, CITATION.cff, README.md

---------------------------------------------------------------------

# Version 1.0.2

+ Update ChangeLog.md, CITATION.cff, MANIFEST.in, README.md
+ Add document website
+ Fix bug in dataset

---------------------------------------------------------------------

# Version 1.0.1

+ Add ChangeLog.md 
+ Update citation
+ Add logo
+ Update requirements libraries

---------------------------------------------------------------------

# Version 1.0.0 (First version)
+ Add project's information (MANIFEST.in, LICENSE, README.md, requirements.txt, CITATION.cff, CODE_OF_CONDUCT.md)
+ Add supported data folder
+ Add utils module
+ Add examples and tests folder
+ Add MetaCluster class
+ Add Github's Action

